EasyExtend.langlets.p4d.p4dbase.P4DAccessError

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class P4DAccessError |
[hide private]
[frames] | no frames]

# Class P4DAccessError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
               exceptions.AttributeError --+
                                           |
                                          P4DAccessError

Instance Methods | [hide private]
Inherited from `exceptions.AttributeError`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`